@@ -1031,6 +1031,26 @@ func RegisterDefaultTranslations(v *validator.Validate, trans ut.Translator) (er
 			translation: "{0}은(는) 알파벳과 숫자만 포함할 수 있습니다.",
 			override:    false,
 		},
+		{
+			tag:         "alphaspace",
+			translation: "{0}은(는) 알파벳과 공백만 포함할 수 있습니다.",
+			override:    false,
+		},
+		{
+			tag:         "alphanumspace",
+			translation: "{0}은(는) 알파벳, 숫자, 공백만 포함할 수 있습니다.",
+			override:    false,
+		},
+		{
+			tag:         "alphaunicode",
+			translation: "{0}은(는) 유니코드 문자만 포함할 수 있습니다.",
+			override:    false,
+		},
+		{
+			tag:         "alphanumunicode",
+			translation: "{0}은(는) 유니코드 문자와 숫자만 포함할 수 있습니다.",
+			override:    false,
+		},
 		{
 			tag:         "numeric",
 			translation: "{0}은(는) 올바른 숫자여야 합니다.",
